| InterventionParameters-class | R Documentation |
This class hosts the intervention parameters used to create intervention protocols for a SEIRD-class type of model.
startlist of values for start points of intervention intervals (double).
stoplist of values for stop points of intervention intervals (double).
coveragelist of values for effect levels of intervention intervals (double).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.