| SEIRD_CT-class | R Documentation |
This class represents the SEIRD_CT model, which provides a model of contact tracing.
## S4 method for signature 'SEIRD_CT' initial_conditions(object) ## S4 method for signature 'SEIRD_CT' transmission_parameters(object) ## S4 replacement method for signature 'SEIRD_CT' initial_conditions(object) <- value ## S4 replacement method for signature 'SEIRD_CT' transmission_parameters(object) <- value ## S4 method for signature 'SEIRD_CT' run(object, times, solve_method = "lsoda") ## S4 method for signature 'SEIRD_CT' R0(model) ## S4 method for signature 'SEIRD_CT' ode_structure_diagram(model)
object |
an object of the class SEIRD_CT |
value |
(list) list of values for beta, kappa, gamma, mu, respectively. |
times |
(double) a sequence of time points at which the solution to the system of ODEs should be returned. Must be of the form seq(t_start, t_end, by=t_step). Default time series is seq(0, 100, by = 1). |
solve_method |
(string) a string of chosen numerical integration method for solving the ode system. Default is lsoda which is also the default for the ode function in the deSolve package used in this function. |
model |
an SEIRD_CT model |
object of class SEIRD_CT with initial conditions assigned.
object of class SEIRD_CT with transmission parameter values assigned.
two dataframes: one with the time steps, age range, time series of S, E, I and R population fractions, and one with the time steps, age range, time series of incidences and deaths population fraction.
an R0 value
An ODE-compartmental structure diagram object of class html
initial_conditions: Retrieves initial conditions of SEIRD_CT model.
transmission_parameters: Retrieves transmission parameters of SEIRD_CT model.
initial_conditions<-: Setter method for initial conditions (S0, E0, P0, A0, I0, Et0, Pt0, At0, It0, R0)
of the SEIRD_CT model.
All initial conditions must sum up to 1. If the initial conditions provided to do not sum to 1, an error is thrown.
transmission_parameters<-: Set transmission parameters (beta, kappa, gamma and mu)
of the SEIRD_CT model.
If the transmission parameters provided to are not 1-dimensional an error is thrown.
run: Solves ODEs of the SEIRD_CT specified in object
for the time points specified in times and integration method specified in
solve_method.
\frac{dS(t)}{dt} = - (beta (P(t) + I(t)) + beta_a A(t)) S(t)
\frac{dE(t)}{dt} = beta (1 - chi) (P(t) + I(t)) S(t) + beta_a A(t) S(t) - omega E(t)
\frac{dP(t)}{dt} = (1 - eta_a) omega E(t) - psi P(t)
\frac{dA(t)}{dt} = eta_a omega E(t) - gamma A(t)
\frac{dI(t)}{dt} = (1 - phi) psi P(t) - (gamma + mu) I(t)
\frac{dEt(t)}{dt} = beta chi (P(t) + I(t)) S(t) - omega E(t)
\frac{dPt(t)}{dt} = (1 - eta_a) omega Et(t) - psi Pt(t)
\frac{dAt(t)}{dt} = eta_a omega Et(t) - gamma At(t)
\frac{dIt(t)}{dt} = psi Pt(t) - phi psi P(t) - (gamma + mu) It(t)
\frac{dR(t)}{dt} = gamma (I(t) + It(t) + A(t) + At(t))
\frac{dD(t)}{dt} = mu (I(t) + It(t))
\frac{dC(t)}{dt} = (beta (P(t) + I(t)) + beta_a A(t)) S(t)
This function relies on the package deSolve.
R0: Calculates basic reproduction number for SEIRD_CT model
The R0 parameter is given by:
R_0 = η_aβ_a/γ + (1 - η_a)(1 - χ) [β/ψ + (1-φ) β/(γ+μ)]
ode_structure_diagram: Prints a compartmental diagram for the SEIRD_CT model
output_nameslist of compartments name which are used by the model and incidence.
initial_condition_nameslist of names of initial conditions (characters). Default is list("S0", "E0", "P0", "A0", "I0", "Et0", "Pt0", "At0", "It0", "R0").
transmission_parameter_nameslist of names of transmission parameters (characters). Default is list("beta", "beta_a", "gamma", "mu", "chi", "omega", "eta_a", "psi", "phi").
initial_conditionslist of values for initial conditions (double).
transmission_parameterslist of values for transmission parameters (double).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.